cldoc is a clang based documentation generator for C and C++. cldoc tries to
solve the issue of writing C/C++ software documentation with a modern,
non-intrusive and robust approach.

# Features
* Uses clang to robustly parse even the most complex C++ projects without
  additional effort from the user.
* Requires zero configuration.
* Uses markdown for documentation formatting.
* Generates an xml description of the API which can be reused for other purposes.
* Uses a simple format for documenting your code.
* Supports cross-referencing in documentation.
* Generates a single file, javascript based web application to render the documentation.
* Integrates seamlessly with your existing website.
* Lightning fast client-side searching using a pregenerated search index.
* Generates a formatted documentation coverage report and integrates it in the
  website.

For more information, please visit http://jessevdk.github.com/cldoc.

# Get started now!
To get started using cldoc, please have a look at
[Getting started](http://jessevdk.github.com/cldoc/gettingstarted.html) to install cldoc. Then explore how
to [document your code](http://jessevdk.github.com/cldoc/documenting.html) so that cldoc can extract it. Finally
go and read [Generating site](http://jessevdk.github.com/cldoc/generating.html) to find out how to use the cldoc
command in your project to generate the documentation.

# Example
For an easy introduction into using cldoc, please have a look at the
[example project](https://github.com/jessevdk/cldoc/tree/master/example) and corresponding
generated [documentation](http://jessevdk.github.com/cldoc/example/).
